==> dnet-openaireplus-mapping-utils-3.5.7-20160613.154258-3-sources.jar: eu/dnetlib/data/index/CloudIndexClient.java <==
package eu.dnetlib.data.index;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import eu.dnetlib.functionality.index.solr.feed.StreamingInputDocumentFactory;
import eu.dnetlib.miscutils.datetime.HumanTime;
import eu.dnetlib.miscutils.functional.UnaryFunction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.solr.client.solrj.SolrQuery;
import org.apache.solr.client.solrj.impl.CloudSolrServer;
import org.apache.solr.client.solrj.response.QueryResponse;
import org.apache.solr.client.solrj.response.UpdateResponse;
import org.apache.solr.common.SolrInputDocument;

/**
 * Created by michele on 11/11/15.
 */
public class CloudIndexClient {

	private static final Log log = LogFactory.getLog(CloudIndexClient.class);
	private static final String INDEX_RECORD_RESULT_FIELD = "dnetResult";

	private final CloudSolrServer solrServer;

	protected CloudIndexClient(final CloudSolrServer solrServer) {
		this.solrServer = solrServer;
	}

	public int feed(final String record, final String indexDsId, final UnaryFunction<String, String> toIndexRecord) throws CloudIndexClientException {
		try {
			final SolrInputDocument doc = prepareSolrDocument(record, indexDsId, toIndexRecord);
			if ((doc == null) || doc.isEmpty()) throw new CloudIndexClientException("Invalid solr document");
			return feed(doc);
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error feeding document", e);
		}
	}

	public int feed(final SolrInputDocument document) throws CloudIndexClientException {
		try {
			final UpdateResponse res = solrServer.add(document);
			log.debug("feed time for single records, elapsed time: " + HumanTime.exactly(res.getElapsedTime()));
			if (res.getStatus() != 0) {
				throw new CloudIndexClientException("bad status: " + res.getStatus());
			}
			solrServer.commit();
			return res.getStatus();
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error feeding document", e);
		}
	}

	public void feed(final List<SolrInputDocument> docs, final AfterFeedingCallback callback) throws CloudIndexClientException {
		try {
			final UpdateResponse res = solrServer.add(docs);
			log.debug("feed time for " + docs.size() + " records, elapsed tipe: : " + HumanTime.exactly(res.getElapsedTime()));
			solrServer.commit();
			if (callback != null) {
				callback.doAfterFeeding(res);
			}
			if (res.getStatus() != 0) throw new CloudIndexClientException("bad status: " + res.getStatus());
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error feeding documents", e);
		}
	}

	public SolrInputDocument prepareSolrDocument(final String record, final String indexDsId, final UnaryFunction<String, String> toIndexRecord)
			throws CloudIndexClientException {
		try {
			final StreamingInputDocumentFactory documentFactory = new StreamingInputDocumentFactory();

			final String version = (new SimpleDateFormat("yyyy-MM-dd\'T\'hh:mm:ss\'Z\'")).format(new Date());
			final String indexRecord = toIndexRecord.evaluate(record);

			if (log.isDebugEnabled()) {
				log.debug("***************************************\nSubmitting index record:\n" + indexRecord + "\n***************************************\n");
			}

			return documentFactory.parseDocument(version, indexRecord, indexDsId, INDEX_RECORD_RESULT_FIELD);
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error creating solr document", e);
		}
	}

	public boolean isRecordIndexed(final String id) throws CloudIndexClientException {
		try {
			final SolrQuery query = new SolrQuery();
			query.setQuery("objidentifier:\"" + id + "\"");
			final QueryResponse res = solrServer.query(query);
			return res.getResults().size() > 0;
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error searching documents", e);
		}
	}

	public void close() {
		if (solrServer != null) {
			solrServer.shutdown();
		}
	}

	public interface AfterFeedingCallback {

		void doAfterFeeding(final UpdateResponse response);
	}
}

==> dnet-openaireplus-mapping-utils-3.6.2-20160909.080123-14-sources.jar: eu/dnetlib/data/index/CloudIndexClient.java <==
package eu.dnetlib.data.index;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.solr.client.solrj.SolrQuery;
import org.apache.solr.client.solrj.impl.CloudSolrServer;
import org.apache.solr.client.solrj.response.QueryResponse;
import org.apache.solr.client.solrj.response.UpdateResponse;
import org.apache.solr.common.SolrInputDocument;

import eu.dnetlib.functionality.index.solr.feed.StreamingInputDocumentFactory;
import eu.dnetlib.miscutils.datetime.HumanTime;
import eu.dnetlib.miscutils.functional.UnaryFunction;

/**
 * Created by michele on 11/11/15.
 */
public class CloudIndexClient {

	private static final Log log = LogFactory.getLog(CloudIndexClient.class);
	private static final String INDEX_RECORD_RESULT_FIELD = "dnetResult";

	private final CloudSolrServer solrServer;

	protected CloudIndexClient(final CloudSolrServer solrServer) {
		this.solrServer = solrServer;
	}

	public int feed(final String record, final String indexDsId, final UnaryFunction<String, String> toIndexRecord) throws CloudIndexClientException {
		try {
			final SolrInputDocument doc = prepareSolrDocument(record, indexDsId, toIndexRecord);
			if ((doc == null) || doc.isEmpty()) throw new CloudIndexClientException("Invalid solr document");
			return feed(doc);
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error feeding document", e);
		}
	}

	public int feed(final SolrInputDocument document) throws CloudIndexClientException {
		try {
			final UpdateResponse res = solrServer.add(document);
			log.debug("feed time for single records, elapsed time: " + HumanTime.exactly(res.getElapsedTime()));
			if (res.getStatus() != 0) { throw new CloudIndexClientException("bad status: " + res.getStatus()); }
			solrServer.commit();
			return res.getStatus();
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error feeding document", e);
		}
	}

	public void feed(final List<SolrInputDocument> docs, final AfterFeedingCallback callback) throws CloudIndexClientException {
		try {
			if (docs.isEmpty()){
				log.debug("Empty list of documents. Calling callback, if needed.");
				if (callback != null) {
					callback.doAfterFeeding(null);
				}
				return;
			}
			final UpdateResponse res = solrServer.add(docs);
			log.debug("feed time for " + docs.size() + " records, elapsed tipe: : " + HumanTime.exactly(res.getElapsedTime()));
			solrServer.commit();
			if (callback != null) {
				callback.doAfterFeeding(res);
			}
			if (res.getStatus() != 0) throw new CloudIndexClientException("bad status: " + res.getStatus());
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error feeding documents", e);
		}
	}

	public SolrInputDocument prepareSolrDocument(final String record, final String indexDsId, final UnaryFunction<String, String> toIndexRecord)
			throws CloudIndexClientException {
		try {
			final StreamingInputDocumentFactory documentFactory = new StreamingInputDocumentFactory();

			final String version = (new SimpleDateFormat("yyyy-MM-dd\'T\'hh:mm:ss\'Z\'")).format(new Date());
			final String indexRecord = toIndexRecord.evaluate(record);

			if (log.isDebugEnabled()) {
				log.debug("***************************************\nSubmitting index record:\n" + indexRecord + "\n***************************************\n");
			}

			return documentFactory.parseDocument(version, indexRecord, indexDsId, INDEX_RECORD_RESULT_FIELD);
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error creating solr document", e);
		}
	}

	public boolean isRecordIndexed(final String id) throws CloudIndexClientException {
		try {
			final SolrQuery query = new SolrQuery();
			query.setQuery("objidentifier:\"" + id + "\"");
			final QueryResponse res = solrServer.query(query);
			return res.getResults().size() > 0;
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error searching documents", e);
		}
	}

	public int remove(final String id) throws CloudIndexClientException {
		try {
			final UpdateResponse res = solrServer.deleteByQuery("objidentifier:\"" + id + "\"");
			return res.getResponse().size();
		} catch (final Throwable e) {
			throw new CloudIndexClientException("Error searching documents", e);
		}
	}

	public void close() {
		if (solrServer != null) {
			solrServer.shutdown();
		}
	}

	public interface AfterFeedingCallback {

		void doAfterFeeding(final UpdateResponse response);
	}
}
